# di: pythonic dependency injection

[![codecov](https://codecov.io/gh/adriangb/di/branch/main/graph/badge.svg?token=A0FXC8B93Y)](https://codecov.io/gh/adriangb/di)
![Test & Release](https://github.com/adriangb/di/actions/workflows/release.yaml/badge.svg)

⚠️ This project is a WIP. Until there is a 1.X.Y release, expect breaking changes. ⚠️

For more information, see our [docs].

[docs]: https://www.adriangb.com/di/

See this release on GitHub: [v0.28.9](https://github.com/adriangb/di/releases/tag/0.28.9)
